@@ -67,6 +67,7 @@ class RefsSnapshot:
         self.oi = parse["oi"]
         self.upperBand = parse["upperBand"]
         self.lowerBand = parse["lowerBand"]
+        
 
 
 class Refs:
@@ -79,5 +80,29 @@ class Refs:
         self.segmentId = parse["segmentId"]
         self.price = parse["price"]
 
+class Greeks:
+    def __init__(self, json_msg):
+        for i in json_msg:
+            jsonStr = json.dumps(i)
+            parse = json.loads(jsonStr)
+        self.kind = parse["kind"]
+        self.ticker = parse["ticker"]
+        self.iv = parse["iv"]
+        self.delta = parse["delta"]
+        self.theta = parse["theta"]
+        self.vega = parse["vega"]
+        self.gamma = parse["gamma"]
+        self.ivvwap = parse["ivvwap"]
+        self.vanna = parse["vanna"]
+        self.charm = parse["charm"]
+        self.speed = parse["speed"]
+        self.zomma = parse["zomma"]
+        self.color = parse["color"]
+        self.volga = parse["volga"]
+        self.veta = parse["veta"]
+        self.tgr = parse["tgr"]
+        self.tv = parse["tv"]
+        self.dtr = parse["dtr"]
+
 
 # End Module
